% GENERAL INFORMATION
% this program calulates the numbers in tables 1-3
% the data used are from the file mvd.dat

load mvd.dat

standard_error=1;
bootstrap=100;

ky=mvd(:,19)==16;
mvd_ky=mvd(ky,:);              % only the kentucky data are used
y=mvd_ky(:,1);
head=mvd_ky(:,10)==1;
neck=mvd_ky(:,11)==1;
upper_extr=mvd_ky(:,12)==1;
trunk=mvd_ky(:,13)==1;
low_back=mvd_ky(:,14)==1;
lower_extr=mvd_ky(:,15)==1;
occ_dis=mvd_ky(:,16)==1;
male=mvd_ky(:,5);
marital=mvd_ky(:,6);
age=mvd_ky(:,20);
manu=mvd_ky(:,8);
constr=mvd_ky(:,9);
prev_earn=mvd_ky(:,21);
ind=(age<99) &(marital<8) & (male<9) & (manu<8) & (constr<8) & (mvd_ky(:,18)<9);
sum(ind)
ind=ones(length(ind),1);
mvd_ky_clean=mvd_ky(ind==1,:);

prev_earn=mvd_ky_clean(:,21);
y=mvd_ky_clean(:,1);
head=mvd_ky_clean(:,10)==1;
neck=mvd_ky_clean(:,11)==1;
upper_extr=mvd_ky_clean(:,12)==1;
trunk=mvd_ky_clean(:,13)==1;
low_back=mvd_ky_clean(:,14)==1;
lower_extr=mvd_ky_clean(:,15)==1;
occ_dis=mvd_ky_clean(:,16)==1;
male=mvd_ky_clean(:,5)==1;
marital=mvd_ky_clean(:,6)==1;
age=mvd_ky_clean(:,20);
manu=mvd_ky_clean(:,8);
constr=mvd_ky_clean(:,9);

after=mvd_ky_clean(:,3);
high=mvd_ky_clean(:,4);
clear mvd mvd_ky mvd_ky_clean ky

y=y+0.25*(y==0);   % add 0.25 to zero durations before taking logarithms
ly=log(y);

y00=y((after==0)&(high==0),1);
y01=y((after==1)&(high==0),1);
y10=y((after==0)&(high==1),1);
y11=y((after==1)&(high==1),1);
ly00=ly((after==0)&(high==0),1);
ly01=ly((after==1)&(high==0),1);
ly10=ly((after==0)&(high==1),1);
ly11=ly((after==1)&(high==1),1);

% TABLE 1
% construction of table 1 with summary statistics

tabel1=zeros(4,8);
for i=1:4,
    if i==1,
       yy=y00;
       end
    if i==2
       yy=y01;
       end
    if i==3,
       yy=y10;
       end
    if i==4
       yy=y11;
       end
    lyy=log(yy);   
    myy=mean(yy);
    dyy=yy-myy;
    syy=sqrt(dyy'*dyy/(length(yy)-1));
    mlyy=mean(lyy);
    dlyy=lyy-mlyy;
    slyy=sqrt(dlyy'*dlyy/(length(lyy)-1));
    q25=cumdfinv(0.25,yy); 
    q50=cumdfinv(0.50,yy); 
    q75=cumdfinv(0.75,yy); 
    q90=cumdfinv(0.90,yy); 
    tabel1(i,:)=[myy,syy,mlyy,slyy,q25,q50,q75,q90];
    end,
    
tabel1

% TABLE 2
% construction of table 2 with estimates of effect for treatment group

xx=[ones(length(y),1),after,high,after.*high]; %,log(prev_earn),x];
out=ols(y,xx)
N00=length(y00);
N01=length(y01);
N10=length(y10);
N11=length(y11);

[mean(y00),std(y00);mean(y01),std(y01);mean(y10),std(y10);mean(y11),std(y11)]
outt=[length(y00);length(y01);length(y10);length(y11)]
mean([y00;y01;y10;y11])
median([y00;y01;y10;y11])

did=mean(y11)-mean(y10)-(mean(y01)-mean(y00))
'sample sizes'
[N00,N01,N10,N11]


tabel2=zeros(5,12);
qq=[0.25;0.50;0.75;0.90];
Nq1=length(qq)+1;
% cic estimates
[est,se]=cic(y00,y01,y10,y11,qq,standard_error,bootstrap);
[est;se];

tabel2(3,1)=est(1,Nq1+1);
tabel2(4,1)=est(1,2*Nq1+1);
tabel2(5,1)=est(1,3*Nq1+1);

tabel2(3,2)=se(2,Nq1+1);
tabel2(4,2)=se(2,2*Nq1+1);
tabel2(5,2)=se(2,3*Nq1+1);

tabel2(3,5)=est(1,Nq1+2);
tabel2(4,5)=est(1,2*Nq1+2);
tabel2(5,5)=est(1,3*Nq1+2);

tabel2(3,6)=se(2,Nq1+2);
tabel2(4,6)=se(2,2*Nq1+2);
tabel2(5,6)=se(2,3*Nq1+2);

tabel2(3,7)=est(1,Nq1+3);
tabel2(4,7)=est(1,2*Nq1+3);
tabel2(5,7)=est(1,3*Nq1+3);

tabel2(3,8)=se(2,Nq1+3);
tabel2(4,8)=se(2,2*Nq1+3);
tabel2(5,8)=se(2,3*Nq1+3);

tabel2(3,9)=est(1,Nq1+4);
tabel2(4,9)=est(1,2*Nq1+4);
tabel2(5,9)=est(1,3*Nq1+4);

tabel2(3,10)=se(2,Nq1+4);
tabel2(4,10)=se(2,2*Nq1+4);
tabel2(5,10)=se(2,3*Nq1+4);

tabel2(3,11)=est(1,Nq1+5);
tabel2(4,11)=est(1,2*Nq1+5);
tabel2(5,11)=est(1,3*Nq1+5);

tabel2(3,12)=se(2,Nq1+5);
tabel2(4,12)=se(2,2*Nq1+5);
tabel2(5,12)=se(2,3*Nq1+5);

[est,se]=cic(ly00,ly01,ly10,ly11,qq,standard_error,bootstrap);
[est;se]
tabel2(3,3)=est(1,Nq1+1);
tabel2(4,3)=est(1,2*Nq1+1);
tabel2(5,3)=est(1,3*Nq1+1);

tabel2(3,4)=se(2,Nq1+1);
tabel2(4,4)=se(2,2*Nq1+1);
tabel2(5,4)=se(2,3*Nq1+1);


% standard did in levels estimates
m00=mean(y00);
d00=y00-m00;
v00=d00'*d00/(length(y00)-1);
m01=mean(y01);
d01=y01-m01;
v01=d01'*d01/(length(y01)-1);
m10=mean(y10);
d10=y10-m10;
v10=d10'*d10/(length(y10)-1);
m11=mean(y11);
d11=y11-m11;
v11=d11'*d11/(length(y11)-1);

did=m11-m10-(m01-m00);
% analytic standard error
v_did=v00/length(y00)+v01/length(y01)+v10/length(y10)+v11/length(y11);
s_did=sqrt(v_did);
Nq=length(qq);
est_did=zeros(2+Nq,1);
est_did(1,1)=did;
est_did(2,1)=mean(log(y11))-mean(log(y10+mean(y01)-mean(y00)));
for i=1:Nq,
    est_did(2+i,1)=cumdfinv(qq(i,1),y11)-cumdfinv(qq(i,1),y10+mean(y01)-mean(y00));
    end,

% bootstrap standard errors
boot_did=zeros(bootstrap,Nq+2);
for i=1:bootstrap,
    u=floor(length(y00)*rand(length(y00),1)+1);
    y00_b=y00(u,1);
    u=floor(length(y01)*rand(length(y01),1)+1);
    y01_b=y01(u,1);
    u=floor(length(y10)*rand(length(y10),1)+1);
    y10_b=y10(u,1);
    u=floor(length(y11)*rand(length(y11),1)+1);
    y11_b=y11(u,1);
    m00=mean(y00_b);
    m01=mean(y01_b);
    m10=mean(y10_b);
    m11=mean(y11_b);
    did=m11-m10-(m01-m00);
    % analytic standard error
    Nq=length(qq);
    est_b=zeros(2+Nq,1);
    est_b(1,1)=did;
    est_b(2,1)=mean(log(y11_b))-mean(log(y10_b+mean(y01_b)-mean(y00_b)));
    for ii=1:Nq,
    est_b(2+ii,1)=cumdfinv(qq(ii,1),y11_b)-cumdfinv(qq(ii,1),y10_b+mean(y01_b)-mean(y00_b));
        end,
    est_b    
    boot_did(i,:)=est_b';    
    end    

boot_did=real(boot_did);
boot_did=sort(boot_did);
upper=round(0.975*bootstrap);
lower=round(0.025*bootstrap);
sboot=(boot_did(upper,:)-boot_did(lower,:))/(2*1.96);
boot_did=boot_did-ones(bootstrap,1)*(est_did')
boot_did_sq=boot_did.*boot_did;
tabel2(1,1)=est_did(1,1);
tabel2(1,2)=sboot(:,1);
tabel2(1,3)=0;
tabel2(1,4)=0;
for i=1:Nq,
    tabel2(1,2*(i+1)+1)=est_did(2+i,1);
    tabel2(1,2*(i+1)+2)=sboot(:,2+i);
    end,


% standard did in logs estimates
m00=mean(ly00);
d00=ly00-m00;
v00=d00'*d00/(length(ly00)-1);
m01=mean(ly01);
d01=ly01-m01;
v01=d01'*d01/(length(ly01)-1);
m10=mean(ly10);
d10=ly10-m10;
v10=d10'*d10/(length(ly10)-1);
m11=mean(ly11);
d11=ly11-m11;
v11=d11'*d11/(length(ly11)-1);

did=m11-m10-(m01-m00);
% analytic standard error
v_did=v00/length(ly00)+v01/length(ly01)+v10/length(ly10)+v11/length(ly11);
s_did=sqrt(v_did);
Nq=length(qq);
est_did=zeros(2+Nq,1);
est_did(1,1)=did;
est_did(2,1)=mean(exp(ly11))-mean(exp(ly10+mean(ly01)-mean(ly00)));
for i=1:Nq,
    est_did(2+i,1)=cumdfinv(qq(i,1),y11)-cumdfinv(qq(i,1),exp(ly10+mean(ly01)-mean(ly00)));
    end,

boot_did=zeros(bootstrap,Nq+2);
for i=1:bootstrap,
    u=floor(length(ly00)*rand(length(ly00),1)+1);
    ly00_b=ly00(u,1);
    u=floor(length(y01)*rand(length(y01),1)+1);
    ly01_b=ly01(u,1);
    u=floor(length(y10)*rand(length(y10),1)+1);
    ly10_b=ly10(u,1);
    u=floor(length(y11)*rand(length(y11),1)+1);
    ly11_b=ly11(u,1);
    m00=mean(ly00_b);
    m01=mean(ly01_b);
    m10=mean(ly10_b);
    m11=mean(ly11_b);
    did=m11-m10-(m01-m00);
    % analytic standard error
    Nq=length(qq);
    est_b=zeros(2+Nq,1);
    est_b(1,1)=did;
    est_b(2,1)=mean(exp(ly11_b))-mean(exp(ly10_b+mean(ly01_b)-mean(ly00_b)));
    for ii=1:Nq,
    est_b(2+ii,1)=cumdfinv(qq(ii,1),exp(ly11_b))-cumdfinv(qq(ii,1),exp(ly10_b+mean(ly01_b)-mean(ly00_b)));
        end,
    est_b;    
    boot_did(i,:)=est_b';    
    end    

boot_did
boot_did=real(boot_did);
boot_did=sort(boot_did);
upper=round(0.975*bootstrap);
lower=round(0.025*bootstrap);
sboot=(boot_did(upper,:)-boot_did(lower,:))/(2*1.96);
boot_did=boot_did-ones(bootstrap,1)*(est_did');
boot_did_sq=boot_did.*boot_did;
tabel2(2,3)=est_did(1,1);
tabel2(2,4)=sboot(:,1);;
tabel2(2,1)=est_did(2,1);
tabel2(2,2)=sboot(:,2);
for i=1:Nq,
    tabel2(2,2*(i+1)+1)=est_did(2+i,1);
    tabel2(2,2*(i+1)+2)=sboot(:,2+i);
    end,


tabel2

% TABLE 3
% construction of table 3 with estimates of effect for control group


y00=y((after==0)&(high==1),1);
y01=y((after==1)&(high==1),1);
y10=y((after==0)&(high==0),1);
y11=y((after==1)&(high==0),1);
ly00=ly((after==0)&(high==1),1);
ly01=ly((after==1)&(high==1),1);
ly10=ly((after==0)&(high==0),1);
ly11=ly((after==1)&(high==0),1);

xx=[ones(length(y),1),after,high,after.*high]; 
out=ols(y,xx)
N00=length(y00);
N01=length(y01);
N10=length(y10);
N11=length(y11);

[mean(y00),std(y00);mean(y01),std(y01);mean(y10),std(y10);mean(y11),std(y11)]
outt=[length(y00);length(y01);length(y10);length(y11)]
mean([y00;y01;y10;y11])
median([y00;y01;y10;y11])

did=mean(y11)-mean(y10)-(mean(y01)-mean(y00))
'sample sizes'
[N00,N01,N10,N11]


tabel3=zeros(5,12);
qq=[0.25;0.50;0.75;0.90];
Nq1=length(qq)+1;
% cic estimates
[est,se]=cic(y00,y01,y10,y11,qq,standard_error,bootstrap);
[est;se];

tabel3(3,1)=-est(1,Nq1+1);
tabel3(4,1)=-est(1,2*Nq1+1);
tabel3(5,1)=-est(1,3*Nq1+1);

tabel3(3,2)=se(2,Nq1+1);
tabel3(4,2)=se(2,2*Nq1+1);
tabel3(5,2)=se(2,3*Nq1+1);

tabel3(3,5)=-est(1,Nq1+2);
tabel3(4,5)=-est(1,2*Nq1+2);
tabel3(5,5)=-est(1,3*Nq1+2);

tabel3(3,6)=se(2,Nq1+2);
tabel3(4,6)=se(2,2*Nq1+2);
tabel3(5,6)=se(2,3*Nq1+2);

tabel3(3,7)=-est(1,Nq1+3);
tabel3(4,7)=-est(1,2*Nq1+3);
tabel3(5,7)=-est(1,3*Nq1+3);

tabel3(3,8)=se(2,Nq1+3);
tabel3(4,8)=se(2,2*Nq1+3);
tabel3(5,8)=se(2,3*Nq1+3);

tabel3(3,9)=-est(1,Nq1+4);
tabel3(4,9)=-est(1,2*Nq1+4);
tabel3(5,9)=-est(1,3*Nq1+4);

tabel3(3,10)=se(2,Nq1+4);
tabel3(4,10)=se(2,2*Nq1+4);
tabel3(5,10)=se(2,3*Nq1+4);

tabel3(3,11)=-est(1,Nq1+5);
tabel3(4,11)=-est(1,2*Nq1+5);
tabel3(5,11)=-est(1,3*Nq1+5);

tabel3(3,12)=se(2,Nq1+5);
tabel3(4,12)=se(2,2*Nq1+5);
tabel3(5,12)=se(2,3*Nq1+5);

[est,se]=cic(ly00,ly01,ly10,ly11,qq,standard_error,bootstrap);
[est;se]
tabel3(3,3)=-est(1,Nq1+1);
tabel3(4,3)=-est(1,2*Nq1+1);
tabel3(5,3)=-est(1,3*Nq1+1);

tabel3(3,4)=se(2,Nq1+1);
tabel3(4,4)=se(2,2*Nq1+1);
tabel3(5,4)=se(2,3*Nq1+1);


% standard did in levels estimates
m00=mean(y00);
d00=y00-m00;
v00=d00'*d00/(length(y00)-1);
m01=mean(y01);
d01=y01-m01;
v01=d01'*d01/(length(y01)-1);
m10=mean(y10);
d10=y10-m10;
v10=d10'*d10/(length(y10)-1);
m11=mean(y11);
d11=y11-m11;
v11=d11'*d11/(length(y11)-1);

did=m11-m10-(m01-m00);
% analytic standard error
v_did=v00/length(y00)+v01/length(y01)+v10/length(y10)+v11/length(y11);
s_did=sqrt(v_did);
Nq=length(qq);
est_did=zeros(2+Nq,1);
est_did(1,1)=did;
est_did(2,1)=mean(log(y11))-mean(log(y10+mean(y01)-mean(y00)));
for i=1:Nq,
    est_did(2+i,1)=(cumdfinv(qq(i,1),y11)-cumdfinv(qq(i,1),y10+mean(y01)-mean(y00)));
    end,

boot_did=zeros(bootstrap,Nq+2);
for i=1:bootstrap,
    u=floor(length(y00)*rand(length(y00),1)+1);
    y00_b=y00(u,1);
    u=floor(length(y01)*rand(length(y01),1)+1);
    y01_b=y01(u,1);
    u=floor(length(y10)*rand(length(y10),1)+1);
    y10_b=y10(u,1);
    u=floor(length(y11)*rand(length(y11),1)+1);
    y11_b=y11(u,1);
    m00=mean(y00_b);
    m01=mean(y01_b);
    m10=mean(y10_b);
    m11=mean(y11_b);
    did=m11-m10-(m01-m00);
    % analytic standard error
    Nq=length(qq);
    est_b=zeros(2+Nq,1);
    est_b(1,1)=did;
    est_b(2,1)=mean(log(y11_b))-mean(log(y10_b+mean(y01_b)-mean(y00_b)));
    for ii=1:Nq,
    est_b(2+ii,1)=cumdfinv(qq(ii,1),y11_b)-cumdfinv(qq(ii,1),y10_b+mean(y01_b)-mean(y00_b));
        end,
    est_b;    ;
    boot_did(i,:)=est_b';    
    end    

boot_did=real(boot_did);
boot_did=sort(boot_did);
upper=round(0.975*bootstrap);
lower=round(0.025*bootstrap);
sboot=(boot_did(upper,:)-boot_did(lower,:))/(2*1.96)
boot_did=boot_did-ones(bootstrap,1)*(est_did')
boot_did_sq=boot_did.*boot_did;
tabel3(1,1)=-est_did(1,1);
tabel3(1,2)=sboot(:,1);
tabel3(1,3)=0;
tabel3(1,4)=0;
for i=1:Nq,
    tabel3(1,2*(i+1)+1)=-est_did(2+i,1);
    tabel3(1,2*(i+1)+2)=sboot(:,2+i);
    end,


% standard did in logs estimates
m00=mean(ly00);
d00=ly00-m00;
v00=d00'*d00/(length(ly00)-1);
m01=mean(ly01);
d01=ly01-m01;
v01=d01'*d01/(length(ly01)-1);
m10=mean(ly10);
d10=ly10-m10;
v10=d10'*d10/(length(ly10)-1);
m11=mean(ly11);
d11=ly11-m11;
v11=d11'*d11/(length(ly11)-1);

did=m11-m10-(m01-m00);
% analytic standard error
v_did=v00/length(ly00)+v01/length(ly01)+v10/length(ly10)+v11/length(ly11);
s_did=sqrt(v_did);
Nq=length(qq);
est_did=zeros(2+Nq,1);
est_did(1,1)=did;
est_did(2,1)=mean(exp(ly11))-mean(exp(ly10+mean(ly01)-mean(ly00)));
for i=1:Nq,
    est_did(2+i,1)=cumdfinv(qq(i,1),y11)-cumdfinv(qq(i,1),exp(ly10+mean(ly01)-mean(ly00)));
    end,

% bootstrap standard errors
boot_did=zeros(bootstrap,Nq+2);
for i=1:bootstrap,
    u=floor(length(ly00)*rand(length(ly00),1)+1);
    ly00_b=ly00(u,1);
    u=floor(length(y01)*rand(length(y01),1)+1);
    ly01_b=ly01(u,1);
    u=floor(length(y10)*rand(length(y10),1)+1);
    ly10_b=ly10(u,1);
    u=floor(length(y11)*rand(length(y11),1)+1);
    ly11_b=ly11(u,1);
    m00=mean(ly00_b);
    m01=mean(ly01_b);
    m10=mean(ly10_b);
    m11=mean(ly11_b);
    did=m11-m10-(m01-m00);
    % analytic standard error
    Nq=length(qq);
    est_b=zeros(2+Nq,1);
    est_b(1,1)=did;
    est_b(2,1)=mean(exp(ly11_b))-mean(exp(ly10_b+mean(ly01_b)-mean(ly00_b)));
    for ii=1:Nq,
    est_b(2+ii,1)=cumdfinv(qq(ii,1),exp(ly11_b))-cumdfinv(qq(ii,1),exp(ly10_b+mean(ly01_b)-mean(ly00_b)));
        end,
    est_b;    
    boot_did(i,:)=est_b';    
    end    

boot_did=real(boot_did);
boot_did=sort(boot_did);
upper=round(0.975*bootstrap);
lower=round(0.025*bootstrap);
sboot=(boot_did(upper,:)-boot_did(lower,:))/(2*1.96);
boot_did=boot_did-ones(bootstrap,1)*(est_did')
boot_did_sq=boot_did.*boot_did;
tabel3(2,3)=-est_did(1,1);
tabel3(2,4)=sboot(:,1);
tabel3(2,1)=-est_did(2,1);
tabel3(2,2)=sboot(:,2);
for i=1:Nq,
    tabel3(2,2*(i+1)+1)=-est_did(2+i,1);
    tabel3(2,2*(i+1)+2)=sboot(:,2+i);
    end,

tabel33=tabel3;
tabel3(4,:)=tabel33(5,:);
tabel3(5,:)=tabel33(4,:);
clear tabel33;

tabel1
tabel2
tabel3


%save table123 tabel1 tabel2 tabel3 bootstrap
