% main simulation program
% GENERAL INFORMATION
% main simulation program
% this program does the calculations for table 4

% parameters for data generating process
beta00=-1.5;
beta01=0.5;
beta10=0.4;
beta11=1;
N00=100;
N01=100;
N10=100;
N11=100;
N=400;
alpha00=1/4;
alpha01=1/4;
alpha10=1/4;
alpha11=1/4;

Nsim=10000;
csim=100;
qq=[0.5];
standard_error=1;
bootstrap=1000;

% load in current output from previous part of simulations
load out_sim_05dec19

start_isim=isim;

for isim=start_isim+1:Nsim,
    isim
    u=rand(N,1);
    I00=u<alpha00;
    I01=(u<(alpha00+alpha01)).*(1-I00);
    I10=(u<(alpha00+alpha01+alpha10)).*(1-I00-I01);
    I11=1-I00-I01-I10;
    N00=sum(I00);
    N01=sum(I01);
    N10=sum(I10);
    N11=sum(I11);
    [Y00,Y01,Y10,Y11,D00,D01,D10,D11,B00,B01,B10,B11]=gen(beta00,beta01,beta10,beta11,N00,N01,N10,N11);
    
  
    % 1. estimate based binary data
    [est,se]=cic(B00,B01,B10,B11,qq,standard_error,bootstrap);
    out_bin(isim,:)=[est(:,1),est(:,3),est(:,5),est(:,7),se(1,1),se(1,3),se(1,5),se(1,7),se(2,1),se(2,3),se(2,5),se(2,7)];

    % 2. estimate based discrete data
    [est,se]=cic(D00,D01,D10,D11,qq,standard_error,bootstrap);
    out_dis(isim,:)=[est(:,1),est(:,3),est(:,5),est(:,7),se(1,1),se(1,3),se(1,5),se(1,7),se(2,1),se(2,3),se(2,5),se(2,7)];

    % 3. estimate based continuous data
    [est,se]=cic(Y00,Y01,Y10,Y11,qq,standard_error,bootstrap);
    out_con(isim,:)=[est(:,1),est(:,3),est(:,5),est(:,7),se(1,1),se(1,3),se(1,5),se(1,7),se(2,1),se(2,3),se(2,5),se(2,7)];

    if floor(isim/csim)*csim==isim,
       cont_data_true=-0.1093;
       disc_data_upper_true=-0.0705;
       disc_data_lower_true=-0.1539;
       bin_data_upper_true=0.0375;
       bin_data_lower_true=-0.1875;
       
       bin(1:isim,:)=out_bin(1:isim,:);
       dis(1:isim,:)=out_dis(1:isim,:);
       con(1:isim,:)=out_con(1:isim,:);
       
       % take out truth
       % for continuous estimator take out true effect
       bin(1:isim,1)=out_bin(1:isim,1)-cont_data_true;
       dis(1:isim,1)=out_dis(1:isim,1)-cont_data_true;
       con(1:isim,1)=out_con(1:isim,1)-cont_data_true;
       
       % for dci estimator take out true effect
       bin(1:isim,2)=out_bin(1:isim,2)-cont_data_true;
       dis(1:isim,2)=out_dis(1:isim,2)-cont_data_true;
       con(1:isim,2)=out_con(1:isim,2)-cont_data_true;
       
       % for lower bound estimator take out true lower bound
       bin(1:isim,3)=out_bin(1:isim,3)-bin_data_lower_true;
       dis(1:isim,3)=out_dis(1:isim,3)-disc_data_lower_true;
       con(1:isim,3)=out_con(1:isim,3)-cont_data_true;
       
       % for upper bound estimator take out true upper bound
       bin(1:isim,4)=out_bin(1:isim,4)-bin_data_upper_true;
       dis(1:isim,4)=out_dis(1:isim,4)-disc_data_upper_true;
       con(1:isim,4)=out_con(1:isim,4)-cont_data_true;
       
       % create output for Table 4 in paper
       tabel4=zeros(12,6);
       err_c=con(1:isim,1:4);
       err_d=dis(1:isim,1:4);
       err_b=bin(1:isim,1:4);
       
       % column 1 mean bias
       tabel4(1:4,1)=mean(err_c)';
       tabel4(5:8,1)=mean(err_d)';
       tabel4(9:12,1)=mean(err_b)';
       
       % column 2 median bias
       tabel4(1:4,2)=median(err_c)';
       tabel4(5:8,2)=median(err_d)';
       tabel4(9:12,2)=median(err_b)';
       
       % column 3 root mean squared error
       tabel4(1:4,3)=sqrt(mean(err_c.*err_c))';
       tabel4(5:8,3)=sqrt(mean(err_d.*err_d))';
       tabel4(9:12,3)=sqrt(mean(err_b.*err_b))';
       
       % column 4 median absolute error
       tabel4(1:4,4)=(median(abs(err_c)))';
       tabel4(5:8,4)=(median(abs(err_d)))';
       tabel4(9:12,4)=(median(abs(err_b)))';
       
       % column 5 coverage rate for 95% ci (analytic) 
       tabel4(1:4,5)=mean(abs(con(1:isim,1:4)./con(1:isim,5:8))<1.96)';
       tabel4(5:8,5)=mean(abs(dis(1:isim,1:4)./dis(1:isim,5:8))<1.96)';
       tabel4(9:12,5)=mean(abs(bin(1:isim,1:4)./bin(1:isim,5:8))<1.96)';
       
       % column 6 coverage rate for 95% ci (bootstrap) 
       tabel4(1:4,6)=mean(abs(con(1:isim,1:4)./con(1:isim,9:12))<1.96)';
       tabel4(5:8,6)=mean(abs(dis(1:isim,1:4)./dis(1:isim,9:12))<1.96)';
       tabel4(9:12,6)=mean(abs(bin(1:isim,1:4)./bin(1:isim,9:12))<1.96)';
       
       
       tabel4
       
       
       save out_sim_05dec19 isim bin con dis tabel4 out_bin out_con out_dis cont_data_true disc_data_upper_true disc_data_lower_true bin_data_upper_true bin_data_lower_true Nsim bootstrap

       
       end
    end
    
